DescriptorAttr

Struct DescriptorAttr 

pub struct DescriptorAttr(/* private fields */);
Available on ARM only.
ARMv7-A Short-descriptor page table entry flags.

Reference: ARM Architecture Reference Manual ARMv7-A/R Edition Section B3.5: Short-descriptor translation table format

Implementations

Source

impl DescriptorAttr

pub const TYPE_BIT0: Self

Bit[0]: Descriptor type bit 0 Combined with bit[1] to determine descriptor type:

  • 00: Invalid/Fault
  • 01: Page Table (L1) or Large Page (L2)
  • 10: Section (L1) or Small Page (L2)
  • 11: Section (L1, PXN enabled) or Small Page (L2)
pub const TYPE_BIT1: Self

Bit[1]: Descriptor type bit 1

pub const B: Self

Bit[2]: Bufferable (B) - Part of memory type encoding

pub const C: Self

Bit[3]: Cacheable (C) - Part of memory type encoding

pub const XN_SMALL: Self

Bit[4]: Execute Never (XN) for Small Pages

pub const DOMAIN_MASK: Self

Bits[5:4]: Domain for Sections (only applies to L1 Section entries)

pub const IMP: Self

Bit[9]: Implementation defined

pub const AP0: Self

Bits[11:10]: Access Permission bits [1:0] AP[2:0] encoding (with AP[2] from bit 15):

  • 000: No access
  • 001: Privileged RW, User no access
  • 010: Privileged RW, User RO
  • 011: Privileged RW, User RW
  • 101: Privileged RO, User no access
  • 110: Privileged RO, User RO (deprecated)
  • 111: Privileged RO, User RO
pub const AP1: Self

Bit[11]: Access Permission bit 1

pub const TEX0: Self

Bits[14:12]: Type Extension (TEX) - Extended memory type

pub const TEX1: Self

Bit[13]: Type Extension bit 1

pub const TEX2: Self

Bit[14]: Type Extension bit 2

pub const AP2: Self

Bit[15]: Access Permission bit [2]

pub const S: Self

Bit[16]: Shareable (S)

pub const NG: Self

Bit[17]: Not Global (nG)

pub const NS: Self

Bit[18]: For Section: Not Secure (NS)

pub const SECTION: Self

Section descriptor type (1MB block)

pub const PAGE_TABLE: Self

Page table descriptor type (points to L2)

pub const SMALL_PAGE: Self

Small page descriptor type (4KB page in L2)

pub const NORMAL_MEMORY: Self

Normal memory attributes (Inner/Outer Write-Back, Write-Allocate, Cacheable) TEX=001, C=1, B=1 -> Normal memory, Cacheable

pub const DEVICE_MEMORY: Self

Device memory attributes (Device, nGnRnE) TEX=000, C=0, B=1 -> Device memory

pub const NORMAL_SHAREABLE: Self

Shareable attribute for normal memory

pub const AP_PRIV_RW: Self

Access permission: Privileged RW, User no access

pub const AP_USER_RW: Self

Access permission: Privileged RW, User RW

pub const AP_PRIV_RO: Self

Access permission: Privileged RO, User no access

pub const AP_USER_RO: Self

Access permission: Privileged RO, User RO

Source

impl DescriptorAttr

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl DescriptorAttr

pub const fn iter(&self) -> Iter<DescriptorAttr>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<DescriptorAttr>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl DescriptorAttr

pub const fn common_flags(flags: MappingFlags) -> u32

Returns the common flags for both Section (L1) and Small Page (L2) descriptors.

pub const fn from_mapping_flags_section(flags: MappingFlags) -> Self

Creates descriptor attributes from MappingFlags for a Section (1MB).

pub const fn from_mapping_flags_small_page(flags: MappingFlags) -> Self

Creates descriptor attributes from MappingFlags for a Small Page (4KB).

pub const fn descriptor_type(&self) -> u32

Returns the descriptor type.

pub const fn is_valid(&self) -> bool

Checks if this is a valid descriptor.

pub const fn is_section(&self) -> bool

Checks if this is a Section descriptor (L1).

pub const fn is_page_table(&self) -> bool

Checks if this is a Page Table descriptor (L1).

pub const fn is_small_page(&self) -> bool

Checks if this is a Small Page descriptor (L2).